[pypy-commit] pypy nditer-external_loop: whoops, partial commit

mattip noreply at buildbot.pypy.org
Sat Nov 1 21:48:29 CET 2014


Author: mattip <matti.picus at gmail.com>
Branch: nditer-external_loop
Changeset: r74319:6a505b52a29d
Date: 2014-10-31 01:14 +0200
http://bitbucket.org/pypy/pypy/changeset/6a505b52a29d/

Log:	whoops, partial commit

diff --git a/pypy/module/micronumpy/nditer.py b/pypy/module/micronumpy/nditer.py
--- a/pypy/module/micronumpy/nditer.py
+++ b/pypy/module/micronumpy/nditer.py
@@ -180,7 +180,7 @@
     # and in nditer's with 'external_loop' flag
     can_coalesce = True
     if it.order == 'F':
-        indxs = slice(1,None)
+        fastest = 0
     else:
         fastest = -1
     for idim in range(it.ndim - 1):
@@ -246,7 +246,7 @@
         new_backstrides = backstrides[:-1]
         _shape = shape[-1] * old_iter.slice_shape
         # use the operand's iterator's rightmost stride,
         # even if it is larger than minimum (for 'F' or swapped axis)
         _stride = old_iter.slice_stride
         _backstride = (_shape - 1) * _stride
         new_iter = SliceIter(old_iter.array, old_iter.size / shape[-1],
@@ -246,7 +246,7 @@
         _shape = shape[-1] * old_iter.slice_shape
         # use the operand's iterator's rightmost stride,
-        # even if it is larger than minimum (for 'F' or swapped axis)
+        # even if it is not the fastest (for 'F' or swapped axis)
         _stride = old_iter.slice_stride
         _backstride = (_shape - 1) * _stride


More information about the pypy-commit mailing list